Module subscribing_handler

Module subscribing_handler 

The subscribing_handler module creates Subscribers from arbitrary Handlers.

subscribing handler diagram

Modules

prelude
Exposes the SubscribingHandler type at the library level.

Structs

SubscribingHandler
Provides the Subscriber and Handler traits for a wrapped Handler delegate.

Traits

IntoSubscriber
Provides the ability to convert a Handler into a SubscribingHandler, for use as a Subscriber.