AbstractFactory

Trait AbstractFactory 

pub trait AbstractFactory<T> {
    // Required method
    fn create(&self) -> T;
}
This trait enables the abstraction of the creation of objects.

Required Methods

fn create(&self) -> T

Executes the creation logic and provides the type back to the caller.

Implementors

Source

impl<D, R> AbstractFactory<R> for Lambda<D, R>
where D: Emitter<R>,