Module hashable

Module hashable 

Contains an implementation of Command which requires the instantiation to supply a method of determining both Hash and Eq. Can be used with observer::HashSubject.

Structs

Hashable
Delegates Command::execute calls to a delegate command while delegating Eq and Hash to an id object.