RefCellBox

Struct RefCellBox 

pub struct RefCellBox<T, F, W>
where F: Emitter<T>, W: Handler<RefCell<T>>,
{ /* private fields */ }
Holds a list of allocated objects in a scalable pool. Previously allocated objects can be checked back in after use, to prevent immediate deallocation.

Implementations

Source

impl<T, F, W> RefCellBox<T, F, W>
where F: Emitter<T>, W: Handler<RefCell<T>>,

pub fn new( unused_pool: Vec<Box<RefCell<T>>>, new_gen: F, grow_size: u8, washer: W, ) -> RefCellBox<T, F, W>

Creates a new RefCellBox.

pub fn unused_pool_size(&self) -> usize

Gets the current number of un-checked-out items in the pool. The current “reserve” size.

pub fn expand(&mut self)

Grows the RefCellBox pool by the previously specified quantity.