Module simple

Module simple 

Implements a basic wrapper Context which contains a generic State object.

Structs

SimpleContext
A basic implementation of Context. Stores the current generic State, and possibly transitions to a new state when Context::handle is called.