pub trait Context<S>where
S: State,{
// Required method
fn handle(&mut self);
}Expand description
This trait holds the active state, and acts as a persistent handle for the state machine, which could otherwise be the states themselves.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".