Module primitives

Module primitives 

This module supplies essential types used elsewhere in the library.

Modules

emitter
Provides an encapsulated unit of production.
executable
Provides an encapsulated unit of execution.
handler
Provides types which receive a borrowed value.
prelude
Exposes emitter, executable, handler, and transformer submodules and their preludes at the library level.
transformer
Provides types which receive a borrowed value, and return a new, owned value.