Module executable

Module executable 

Provides an encapsulated unit of execution.

executable diagram

Re-exports

pub use heap::Heap;
pub use lambda::Lambda;

Modules

heap
Provides a heap-based Executable which redirects Executable::execute calls to a delegate Executable. Useful when redirecting calls to unknown or mixed lists of Executables.
lambda
Provides a simple wrapper struct around Delegate, Fn() types.
prelude
Exposes the Executable type at the library level.

Traits

Executable
Encapsulates a block of execution which may be run zero-or-more times.