Heap

Struct Heap 

pub struct Heap { /* private fields */ }
Stores an indirected Executable in a Box for later delegation.

Implementations

Source

impl Heap

pub fn new(delegate: Box<dyn Executable>) -> Self

Creates a new Heap with a given Boxed Executable. # Examples

use roopes::prelude::*;
let my_executable =
    executable::Heap::new(Box::new(executable::Lambda::new(|| {
        println!("Hello World.");
    })));
my_executable.execute();