pub trait Executable {
// Required method
fn execute(&self);
}Expand description
Encapsulates a block of execution which may be run zero-or-more times.
pub trait Executable {
// Required method
fn execute(&self);
}Encapsulates a block of execution which may be run zero-or-more times.