Provides types which receive a borrowed value.
Re-exports
Modules
- hash
- Provides a
HashandEq-implementingHandlerwhich redirectsHandler::handlecalls to a delegateHandler. Useful to allow for handlers to be compared. - heap
- Provides a heap-based
Handlerwhich redirectsHandler::handlecalls to a delegateHandler. Useful when redirecting calls to unknown or mixed lists ofHandlers. - lambda
- Provides a simple wrapper
Lambdastruct aroundDelegate,Fn(&I)types. - prelude
- Exposes the
Handlertype at the library level.
Traits
- Handler
- Defines a primitive interface which handles messages via borrowing.