Heap

Struct Heap 

pub struct Heap<M> { /* private fields */ }
Stores an indirected Handler in a Box for later delegation.

Implementations

Source

impl<M> Heap<M>

pub fn new(delegate: Box<dyn Handler<M>>) -> Heap<M>

Creates a new Heap with a given Boxed Handler. # Examples

use roopes::prelude::*;
let my_handler =
    handler::Heap::new(Box::new(handler::Lambda::new(|message| {
        println!("{message}");
    })));
my_handler.handle(&"Hello World.".to_string());