pub trait AbstractFactory<T> { // Required method fn create(&self) -> T; }
This trait enables the abstraction of the creation of objects.
Executes the creation logic and provides the type back to the caller.