Contains an implementation of HeapPool
which allow client code to generate, use, and
re-use heap-allocated objects efficiently.
Structs
- RefCell
Box - Holds a list of allocated objects in a scalable pool. Previously allocated objects can be checked back in after use, to prevent immediate deallocation.