Contains types which implement the “Observer” pattern, in which a single object is used to delegate notifications to a group of dynamic listening object.
Re-exports
pub use hash_subject::HashSubject;pub use vec_subject::VecSubject;
Modules
- hash_
subject - Contains types which allow
Observers (which implement the appropriateHashandEqtraits) to be removed dynamically. - prelude
- Exposes the
ObserverandSubjecttypes at the library level. - vec_
subject - Contains types which implement the Observer
pattern via an internal
Vec.
Traits
- Attachable
Subject - Allows
Observers to be added to the implementingSubject. - Detachable
Subject - Allows
Observers to be removed from the implementingSubject. - Observer
- An object notified by a
Subject. - Subject
- An object which notifies some group of
Observers. When it is notified, all the listeners are notified.