Module state
roopes_
core
0.1.1
Module state
Module Items
Modules
Traits
In roopes_
core::
patterns
roopes_core
::
patterns
Module
state
This module implements the State pattern.
Modules

prelude
Exposes the
Context
and
State
types at the library level.
simple
Implements a basic wrapper
Context
which contains a generic
State
object.
Traits

Context
This trait holds the active state, and acts as a persistent handle for the state machine, which could otherwise be the states themselves.
State
Provides transitions between states.