Provides an encapsulated unit of execution.
Re-exports
Modules
- heap
- Provides a heap-based
Executablewhich redirectsExecutable::executecalls to a delegateExecutable. Useful when redirecting calls to unknown or mixed lists ofExecutables. - lambda
- Provides a simple wrapper struct around
Delegate,Fn()types. - prelude
- Exposes the
Executabletype at the library level.
Traits
- Executable
- Encapsulates a block of execution which may be run zero-or-more times.