Module handler

Module handler 

Provides types which receive a borrowed value.

handler diagram

Re-exports

pub use hash::Hashable;
pub use heap::Heap;
pub use lambda::Lambda;

Modules

hash
Provides a Hash and Eq-implementing Handler which redirects Handler::handle calls to a delegate Handler. Useful to allow for handlers to be compared.
heap
Provides a heap-based Handler which redirects Handler::handle calls to a delegate Handler. Useful when redirecting calls to unknown or mixed lists of Handlers.
lambda
Provides a simple wrapper Lambda struct around Delegate, Fn(&I) types.
prelude
Exposes the Handler type at the library level.

Traits

Handler
Defines a primitive interface which handles messages via borrowing.